require "bagira/version"
require "pdf-reader"

class Bagira

	FILE_TYPE = { :invalid => 'invalid', :not_found => 'not_found', :pdf => 'pdf', :jpg => 'jpg', :png => 'png' }

	attr_reader :file_type
	attr_reader :filepath
	attr_reader :page_count

  def initialize(filepath)
  	@file_type = FILE_TYPE[:invalid]
  	@file_type = FILE_TYPE[:pdf] unless filepath.match(/\.pdf$/).nil?
  	@file_type = FILE_TYPE[:png] unless filepath.match(/\.png$/).nil?
  	@file_type = FILE_TYPE[:jpg] unless filepath.match(/\.jpg$/).nil?
  	@file_type = FILE_TYPE[:not_found] unless File.exist?(filepath)

  	@filepath = filepath

  	@page_count = 0
  	@page_count = 1 if is_image?
  	if is_document?
  		reader = PDF::Reader.new(filepath)
  		@page_count = reader.page_count
  	end
  end

  def perform_ocr
  	return process_image(@filepath) if is_image?
  	return process_pdf(@filepath) if is_document?
  end

  private
  def process_image(filepath)
  	result = %x(tesseract #{filepath} stdout)
  	return result.strip unless result.nil?
  end

  def process_pdf(filepath)
  	result_array = []
  	for i in 1..@page_count
  		page_result = %x(gs -q -dNOPAUSE -sDEVICE=pnggray -dTextAlphaBits=4 -r300 -sOutputFile=%stdout -dBATCH -dFirstPage=#{i} -dLastPage=#{i} #{filepath}|tesseract stdin stdout)
  		result_array << page_result.strip unless page_result.nil?
  	end
  	result_array.join("\n")
  end

  def is_image?
  	return true if (@file_type.eql?(FILE_TYPE[:jpg]) or @file_type.eql?(FILE_TYPE[:png]))
		return false
  end

  def is_document?
  	return true if (@file_type.eql?(FILE_TYPE[:pdf]))
		return false
  end

end